## Reference Datasets

These datasets are provided as a starting point for exploration and experimentation.

### ::: valency_anndata.datasets.aufstehen

### ::: valency_anndata.datasets.chile_protest

## Polis

### ::: valency_anndata.datasets.polis.load

### ::: valency_anndata.datasets.polis.translate_statements